@@ -1,13 +1,9 @@
 import pandas as pd
-import requests
 from sklearn.decomposition import PCA
-import json
 import matplotlib.pyplot as plt
 import numpy as np
 import matplotlib as mpl
-from highlight_text import ax_text,fig_text
 import mplsoccer
-import highlight_text
 from soccerplots.radar_chart import Radar
 from soccerplots.utils import add_image
 import math
@@ -20,8 +16,8 @@ import seaborn as sns
 import time
 class Euro2020:
     def __init__(self):
-        df = pd.read_csv('fbref.csv',sep=';')
-        df_GK = pd.read_csv('GK_fbref.csv',sep=';')
+        df = pd.read_csv('https://raw.githubusercontent.com/AnabeatrizMacedo241/Euro2020_API/main/Euro2020_API/fbref.csv',sep=';')
+        df_GK = pd.read_csv('https://raw.githubusercontent.com/AnabeatrizMacedo241/Euro2020_API/main/Euro2020_API/GK_fbref.csv',sep=';')
         self.df=df
         self.df_GK=df_GK
     def zptile(self,z_score):
@@ -64,7 +60,6 @@ class Stats(Euro2020):
         cluster1 = model.predict(list1)
         num = int(cluster1)
         players=self.df[(self.df['Cluster'] == num)]
-        print(self.df['Cluster'].value_counts())
         players = players.sort_values(by=['Grade'],ascending=False)
         players = players[['Player', 'Position', 'Age', 'Country', 'Grade']]
         
@@ -120,7 +115,6 @@ class Stats(Euro2020):
         cluster1 = model.predict(list1)
         num = int(cluster1)
         players=self.df[(self.df['Cluster'] == num)]
-        print(self.df['Cluster'].value_counts())
         players = players.sort_values(by=['Grade'],ascending=False)
         players = players[['Player', 'Position', 'Age', 'Country', 'Grade']]
         if len(player_name)==0:
@@ -195,7 +189,7 @@ class Stats(Euro2020):
         self.df['Min_z'] = (self.df['Min'] - meanMin)/stdMin
         self.df['Min_percent'] = self.df['Min_z'].apply(self.zptile)
         self.df['Grade'] = (0.4*self.df['xG_percent']+0.3*self.df['xA_percent']+0.2*self.df['SoT_percent']+0.1*self.df['Min_percent'])*10
-        
+        sns.set(rc={'axes.facecolor':'lightgreen', 'figure.facecolor':'lightgreen'})
         plt.figure(figsize=(16,10))
         sns.scatterplot(data=self.df,x='Salary',y='Grade',hue='Position',size='Salary',sizes=(20, 700))
         plt.title('Forwards & Midfielders Salary X Grade',size=20)
@@ -204,7 +198,6 @@ class Stats(Euro2020):
         plt.text(self.df.Salary[self.df.Player==player1],self.df.Grade[self.df.Player==player1],player1, color='red',fontdict=dict(color='red', alpha=1, size=16))
         plt.text(self.df.Salary[self.df.Player==player2],self.df.Grade[self.df.Player==player2],player2,color='blue',fontdict=dict(color='black', alpha=1, size=16))
         sns.despine(bottom = True, left = True)
-        sns.set(rc={'axes.facecolor':'lightgreen', 'figure.facecolor':'lightgreen'})
         if len(player1)==0:
             raise  ExceptionPlayerName('No results for this player, check if you wrote his name correctly.')    
         if len(player2)==0:
@@ -289,7 +282,7 @@ class Stats(Euro2020):
         self.df['Int_percent'] = self.df['Int_z'].apply(self.zptile)
         
         self.df['Grade'] = (0.3*self.df['Int_percent']+0.2*self.df['TklW_percent']+0.3*self.df['Press_percent']+0.2*self.df['Pass_percent']+(-0.15*self.df['Past'])+0.1*self.df['Min_percent'])*10
-       
+        sns.set(rc={'axes.facecolor':'lightgreen', 'figure.facecolor':'lightgreen'})
         plt.figure(figsize=(16,10))
         sns.scatterplot(data=self.df,x='Salary',y='Grade',hue='Position',size='Salary',sizes=(20, 700))
         plt.title('Defenders & Midfielders Salary X Grade',size=20)
@@ -298,7 +291,6 @@ class Stats(Euro2020):
         plt.text(self.df.Salary[self.df.Player==player1],self.df.Grade[self.df.Player==player1],player1, color='red',fontdict=dict(color='red', alpha=1, size=16))
         plt.text(self.df.Salary[self.df.Player==player2],self.df.Grade[self.df.Player==player2],player2,color='blue',fontdict=dict(color='black', alpha=1, size=16))
         sns.despine(bottom = True, left = True)
-        sns.set(rc={'axes.facecolor':'lightgreen', 'figure.facecolor':'lightgreen'})
         if len(player1)==0:
             raise  ExceptionPlayerName('No results for this player, check if you wrote his name correctly.')    
         if len(player2)==0:
@@ -371,7 +363,7 @@ class Stats(Euro2020):
         self.df_GK['PKsv_z'] = (self.df_GK['PKsv'] - meanPKsv)/stdPKsv
         self.df_GK['PKsv_percent'] = self.df_GK['PKsv_z'].apply(self.zptile)
         self.df_GK['Grade'] = (0.4*self.df_GK['Saves_percent']+0.3*self.df_GK['CS_percent']+(-0.2*self.df_GK['GA_percent'])+0.3*self.df_GK['PKsv_percent'])*10
-       
+        sns.set(rc={'axes.facecolor':'lightgreen', 'figure.facecolor':'lightgreen'})
         plt.figure(figsize=(16,10))
         sns.scatterplot(data=self.df_GK,x='Salary',y='Grade',size='Salary',sizes=(20, 700))
         plt.title('Goalkeepers Salary X Grade',size=20)
@@ -380,7 +372,7 @@ class Stats(Euro2020):
         plt.text(self.df_GK.Salary[self.df_GK.Player==player1],self.df_GK.Grade[self.df_GK.Player==player1],player1, color='red',fontdict=dict(color='red', alpha=1, size=16))
         plt.text(self.df_GK.Salary[self.df_GK.Player==player2],self.df_GK.Grade[self.df_GK.Player==player2],player2,color='blue',fontdict=dict(color='black', alpha=1, size=16))
         sns.despine(bottom = True, left = True)
-        sns.set(rc={'axes.facecolor':'lightgreen', 'figure.facecolor':'lightgreen'})
+        
         
         players = self.df_GK[['Player', 'Age', 'Grade', 'Salary']]
         players = players.sort_values(by=['Grade'],ascending=False)
